@@ -38,7 +38,7 @@ Q_OBJECT
     bool canAddShipOfSizeInVertical(unsigned int size) const;
 public:
     BattleField(Sea* parent, const Coord& size, const bool allow_adjacent_ships);
-    ~BattleField();
+    ~BattleField() override;
 
     bool valid(const Coord& pos) const;
     Element& get(const Coord& pos);
@@ -58,7 +58,7 @@ public:
     void setAllowAdjacentShips(const bool adjacent) { m_allow_adjacent_ships = adjacent; };
     void clear(); // to start placing the ships again in a clean BattleField
     inline unsigned int ships() const { return m_ships; }
-signals:
+Q_SIGNALS:
     void shipDestroyed(Ship*);
 };
 
