@@ -30,7 +30,7 @@ Q_OBJECT
     
     void setHistoryText(int index);
 public:
-    explicit ChatWidget(QWidget* parent = 0);
+    explicit ChatWidget(QWidget* parent = nullptr);
     
     QSize sizeHint() const override;
     void bindTo(Entity* entity);
@@ -41,9 +41,9 @@ public:
 protected:
     bool eventFilter(QObject*, QEvent* e) override;
     void resizeEvent(QResizeEvent*) override;
-signals:
+Q_SIGNALS:
     void message(const QString& text);
-private slots:
+private Q_SLOTS:
     void sendLine();
 };
 
