@@ -22,9 +22,16 @@
 #include <KLineEdit>
 #include <KLocalizedString>
 #include <KSeparator>
-#include <KDNSSD/DNSSD/ServiceBrowser>
-#include <KDNSSD/DNSSD/ServiceModel>
-#include <KDNSSD/DNSSD/PublicService>
+#include <kdnssd_version.h>
+#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+#include <KDNSSD/ServiceBrowser>
+#include <KDNSSD/ServiceModel>
+#include <KDNSSD/PublicService>
+#else
+#include <DNSSD/ServiceBrowser>
+#include <DNSSD/ServiceModel>
+#include <DNSSD/PublicService>
+#endif
 #include <KConfigGroup>
 #include <QDialogButtonBox>
 
@@ -32,7 +39,7 @@
 
 NetworkDialog::NetworkDialog(bool client, QWidget* parent, const QUrl* url)
 : QDialog(parent)
-, m_publisher(0), m_client(client)
+, m_publisher(nullptr), m_client(client)
 {
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
     QVBoxLayout *topLayout = new QVBoxLayout;
@@ -127,8 +134,8 @@ NetworkDialog::NetworkDialog(bool client, QWidget* parent, const QUrl* url)
         
     }
     else {
-        m_hostname = 0;
-        m_games = 0;
+        m_hostname = nullptr;
+        m_games = nullptr;
     
         // port
         tmp = new QLabel(i18n("&Port:"), main);
@@ -213,11 +220,7 @@ void NetworkDialog::slotOkClicked()
             m_feedback->setText(i18n("Connecting to remote host..."));
             m_socket = new QTcpSocket;
             connect(m_socket, &QTcpSocket::connected, this, &NetworkDialog::clientOK);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-            connect(m_socket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &NetworkDialog::clientError);
-#else
-            connect(m_socket, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::errorOccurred), this, &NetworkDialog::clientError);
-#endif
+            connect(m_socket, &QTcpSocket::errorOccurred, this, &NetworkDialog::clientError);
             m_socket->connectToHost(m_hostname->text(), m_port->value());
         }
         else {
@@ -239,7 +242,7 @@ void NetworkDialog::clientOK()
 void NetworkDialog::clientError()
 {
     m_socket->deleteLater();
-    m_socket = 0;
+    m_socket = nullptr;
     m_feedback->setText(i18n("Could not connect to host"));
     m_okButton->setEnabled(true);
 }
